==> atsd_client-2.0.2.tar.gz: atsd_client-2.0.2/setup.py <==
"""
Copyright 2015 Axibase Corporation or its affiliates. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License").
You may not use this file except in compliance with the License.
A copy of the License is located at

https://www.axibase.com/atsd/axibase-apache-2.0.pdf

or in the "license" file accompanying this file. This file is distributed
on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
express or implied. See the License for the specific language governing
permissions and limitations under the License.
"""


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
import re

version = ''
with open('atsd_client/__init__.py', 'r') as fd:
    # noinspection PyRedeclaration
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

print('version:', version)

setup(
    name='atsd_client',
    packages=['atsd_client', 'atsd_client.models'],
    version=version,
    description='Axibase Time-Series Database API Client for Python',
    url='https://github.com/axibase/atsd-api-python',
    author='Axibase Corporation',
    author_email='axibase-api@axibase.com',
    license='Apache 2.0',
    install_requires=['requests','python-dateutil'],
    package_data={'atsd_client': ['connection.properties']},
    keywords='axibase, atsd, axibase time-series database, python',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Operating System :: OS Independent',
        'Topic :: Database',
        'Topic :: Database :: Database Engines/Servers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Monitoring'
    )
)

==> atsd_client-2.0.4.tar.gz: atsd_client-2.0.4/setup.py <==
"""
Copyright 2015 Axibase Corporation or its affiliates. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License").
You may not use this file except in compliance with the License.
A copy of the License is located at

https://www.axibase.com/atsd/axibase-apache-2.0.pdf

or in the "license" file accompanying this file. This file is distributed
on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
express or implied. See the License for the specific language governing
permissions and limitations under the License.
"""


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
import re

version = ''
with open('atsd_client/__init__.py', 'r') as fd:
    # noinspection PyRedeclaration
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

print('version:', version)

setup(
    name='atsd_client',
    packages=['atsd_client', 'atsd_client.models'],
    version=version,
    description='Axibase Time-Series Database API Client for Python',
    url='https://github.com/axibase/atsd-api-python',
    author='Axibase Corporation',
    author_email='axibase-api@axibase.com',
    license='Apache 2.0',
    install_requires=['requests','python-dateutil', 'pandas'],
    package_data={'atsd_client': ['connection.properties']},
    keywords='axibase, atsd, axibase time-series database, python',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Operating System :: OS Independent',
        'Topic :: Database',
        'Topic :: Database :: Database Engines/Servers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Monitoring'
    )
)
